@@ -40,18 +40,17 @@ class Request:
     """
 
     def __init__(self, **kwargs):
-        if consts.ID in kwargs:
-            self.id = kwargs.get(consts.ID)
+        self.id = kwargs.get(consts.ID)
+        self.asset = Asset(**kwargs.get(consts.ASSET))
+        self.status = kwargs.get(consts.STATUS)
+
+        # Validate fields before taking values
         if consts.TYPE in kwargs:
             self.type = kwargs.get(consts.TYPE)
         if consts.NOTE in kwargs:
             self.note = kwargs.get(consts.NOTE)
-        if consts.ASSET in kwargs:
-            self.asset = Asset(**kwargs.get(consts.ASSET))
         if consts.REASON in kwargs:
             self.reason = kwargs.get(consts.REASON)
-        if consts.STATUS in kwargs:
-            self.status = kwargs.get(consts.STATUS)
         if consts.CREATED in kwargs:
             self.created = kwargs.get(consts.CREATED)
         if consts.UPDATED in kwargs:
@@ -75,6 +74,7 @@ class Request:
         if consts.CONTRACT in kwargs:
             self.contract = Named(**kwargs.get(consts.CONTRACT))
 
+    # Accessory methods
     def get_marketplace_id(self):
         return self.marketplace.id
 
@@ -127,8 +127,9 @@ class Param:
     """
 
     def __init__(self, **kwargs):
-        if consts.ID in kwargs:
-            self.id = kwargs.get(consts.ID)
+        self.id = kwargs.get(consts.ID)
+
+        # Validate fields before taking values
         if consts.NAME in kwargs:
             self.name = kwargs.get(consts.NAME)
         if consts.TYPE in kwargs:
@@ -153,12 +154,13 @@ class ConfigurationParam:
     """
 
     def __init__(self, **kwargs):
+        self.id = kwargs.get(consts.ID)
+
+        # Validate fields before taking values
         if consts.VALUE in kwargs:
             self.value = kwargs.get(consts.VALUE)
         if consts.EVENTS in kwargs:
             self.events = Events(**kwargs.get(consts.EVENTS))
-        if consts.ID in kwargs:
-            self.id = kwargs.get(consts.ID)
         if consts.TITLE in kwargs:
             self.title = kwargs.get(consts.TITLE)
         if consts.DESCRIPTION in kwargs:
@@ -258,8 +260,9 @@ class Item(ParamsManager):
         if consts.PARAMS in kwargs:
             super().__init__([Param(**p) for p in kwargs.get(consts.PARAMS)])
 
-        if consts.ID in kwargs:
-            self.id = kwargs.get(consts.ID)
+        self.id = kwargs.get(consts.ID)
+
+        # Validate fields before taking values
         if consts.GLOBAL_ID in kwargs:
             self.GLOBAL_ID = kwargs.get(consts.GLOBAL_ID)
         if consts.MPN in kwargs:
@@ -287,8 +290,9 @@ class Asset(ParamsManager):
         if consts.PARAMS in kwargs:
             super().__init__([Param(**p) for p in kwargs.get(consts.PARAMS)])
 
-        if consts.ID in kwargs:
-            self.id = kwargs.get(consts.ID)
+        self.id = kwargs.get(consts.ID)
+
+        # Validate fields before taking values
         if consts.STATUS in kwargs:
             self.status = kwargs.get(consts.STATUS)
         if consts.EXTERNAL_ID in kwargs:
@@ -319,6 +323,7 @@ class Tiers:
     """
 
     def __init__(self, **kwargs):
+        # Validate fields before taking values
         if consts.CUSTOMER in kwargs:
             self.customer = Tier(**kwargs.get(consts.CUSTOMER))
         if consts.TIER1 in kwargs:
@@ -333,8 +338,9 @@ class Tier:
     """
 
     def __init__(self, **kwargs):
-        if consts.ID in kwargs:
-            self.id = kwargs.get(consts.ID)
+        self.id = kwargs.get(consts.ID)
+
+        # Validate fields before taking values
         if consts.VERSION in kwargs:
             self.version = kwargs.get(consts.VERSION)
         if consts.NAME in kwargs:
@@ -367,6 +373,7 @@ class ContactInfo:
     """
 
     def __init__(self, **kwargs):
+        # Validate fields before taking values
         if consts.ADDRESS_LINE1 in kwargs:
             self.address_line1 = kwargs.get(consts.ADDRESS_LINE1)
         if consts.ADDRESS_LINE2 in kwargs:
@@ -389,6 +396,7 @@ class Contact:
     """
 
     def __init__(self, **kwargs):
+        # Validate fields before taking values
         if consts.FIRST_NAME in kwargs:
             self.first_name = kwargs.get(consts.FIRST_NAME)
         if consts.LAST_NAME in kwargs:
@@ -405,6 +413,7 @@ class PhoneNumber:
     """
 
     def __init__(self, **kwargs):
+        # Validate fields before taking values
         if consts.COUNTRY_CODE in kwargs:
             self.country_code = kwargs.get(consts.COUNTRY_CODE)
         if consts.AREA_CODE in kwargs:
@@ -421,8 +430,9 @@ class Named:
     """
 
     def __init__(self, **kwargs):
-        if consts.ID in kwargs:
-            self.id = kwargs.get(consts.ID)
+        self.id = kwargs.get(consts.ID)
+
+        # Validate fields before taking values
         if consts.NAME in kwargs:
             self.name = kwargs.get(consts.NAME)
 
@@ -434,6 +444,8 @@ class Parent(Named):
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
+
+        # Validate fields before taking values
         if consts.EXTERNAL_ID in kwargs:
             self.external_id = kwargs.get(consts.EXTERNAL_ID)
 
@@ -444,6 +456,7 @@ class Events:
     """
 
     def __init__(self, **kwargs):
+        # Validate fields before taking values
         if consts.CREATED in kwargs:
             self.created = Dated(**kwargs.get(consts.CREATED))
         if consts.UPDATED in kwargs:
@@ -456,6 +469,7 @@ class Dated:
     """
 
     def __init__(self, **kwargs):
+        # Validate fields before taking values
         if consts.AT in kwargs:
             self.at = kwargs.get(consts.AT)
         if consts.BY in kwargs:
@@ -469,6 +483,8 @@ class Marketplace(Named):
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
+
+        # Validate fields before taking values
         if consts.ICON in kwargs:
             self.icon = kwargs.get(consts.ICON)
 
@@ -480,6 +496,8 @@ class Product(Named):
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
+
+        # Validate fields before taking values
         if consts.ICON in kwargs:
             self.icon = kwargs.get(consts.ICON)
         if consts.STATUS in kwargs:
@@ -492,6 +510,7 @@ class Constraints:
     """
 
     def __init__(self, **kwargs):
+        # Validate fields before taking values
         if consts.REQUIRED in kwargs:
             self.required = kwargs.get(consts.REQUIRED)
         if consts.META in kwargs:
@@ -520,8 +539,9 @@ class Connection:
     """
 
     def __init__(self, **kwargs):
-        if consts.ID in kwargs:
-            self.id = kwargs.get(consts.ID)
+        self.id = kwargs.get(consts.ID)
+
+        # Validate fields before taking values
         if consts.TYPE in kwargs:
             self.type = kwargs.get(consts.TYPE)
         if consts.PROVIDER in kwargs:
